@@ -1,6 +1,7 @@
 mod kw;
 mod util;
 
+mod blob;
 mod predicate;
 mod prolog;
 mod term;
@@ -21,3 +22,13 @@ pub fn predicates(stream: TokenStream) -> TokenStream {
 pub fn term(stream: TokenStream) -> TokenStream {
     term::term_macro(stream).into()
 }
+
+#[proc_macro_attribute]
+pub fn arc_blob(attr: TokenStream, item: TokenStream) -> TokenStream {
+    blob::arc_blob_macro(attr, item)
+}
+
+#[proc_macro]
+pub fn wrapped_arc_blob(item: TokenStream) -> TokenStream {
+    blob::wrapped_arc_blob_macro(item)
+}
